"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TableAnswer = exports.AnyAnswer = exports.URLAnswer = exports.TypeaheadSearchAnswer = exports.TextAreaAnswer = exports.TextAnswer = exports.SelectBoxAnswer = exports.RadioButtonsAnswer = exports.NumberAnswer = exports.FilteredSearchAnswer = exports.EmailAnswer = exports.DateRangeAnswer = exports.DatePickerAnswer = exports.CurrencyAnswer = exports.CheckboxesAnswer = exports.BooleanAnswer = void 0;
const zod_1 = require("zod");
const primitiveQuestions_1 = require("./primitiveQuestions");
const Answer = zod_1.z.object({
    type: primitiveQuestions_1.QuestionTypesEnum, // The type of answer
    answer: zod_1.z.string(), // The answer to the question (string)
});
exports.BooleanAnswer = zod_1.z.object({
    type: zod_1.z.literal('boolean'), // The type of answer
    answer: zod_1.z.boolean() // The answer to the question (true/false)
});
exports.CheckboxesAnswer = zod_1.z.object({
    type: zod_1.z.literal('checkBoxes'), // The type of answer
    answer: zod_1.z.array(zod_1.z.string()) // The answer to the question (array of strings)
});
exports.CurrencyAnswer = zod_1.z.object({
    type: zod_1.z.literal('currency'), // The type of answer
    answer: zod_1.z.number() // The answer to the question (number)
});
exports.DatePickerAnswer = Answer.merge(zod_1.z.object({
    type: zod_1.z.literal('datePicker'), // The type of question
}));
exports.DateRangeAnswer = Answer.merge(zod_1.z.object({
    type: zod_1.z.literal('dateRange'), // The type of answer
    answer: zod_1.z.object({
        start: zod_1.z.string(), // The start date (string)
        end: zod_1.z.string() // The end date (string)
    })
}));
exports.EmailAnswer = zod_1.z.object({
    type: zod_1.z.literal('email'), // The type of question
    answer: zod_1.z.string() // The answer to the question (string)
});
exports.FilteredSearchAnswer = Answer.merge(zod_1.z.object({
    type: zod_1.z.literal('filteredSearch'), // The type of answer
    answer: zod_1.z.array(zod_1.z.string()) // The answer to the filtered search (array of strings)
}));
exports.NumberAnswer = zod_1.z.object({
    type: zod_1.z.literal('number'), // The type of answer
    answer: zod_1.z.number() // The answer to the question (number)
});
exports.RadioButtonsAnswer = zod_1.z.object({
    type: zod_1.z.literal('radioButtons'), // The type of answer
    answer: zod_1.z.string() // The answer to the question (string)
});
exports.SelectBoxAnswer = zod_1.z.object({
    type: zod_1.z.literal('selectBox'), // The type of answer
    answer: zod_1.z.string() // The answer to the question (string)
});
exports.TextAnswer = zod_1.z.object({
    type: zod_1.z.literal('text'), // The type of answer
    answer: zod_1.z.string() // The answer to the question (string)
});
exports.TextAreaAnswer = zod_1.z.object({
    type: zod_1.z.literal('textArea'), // The type of answer
    answer: zod_1.z.string() // The answer to the question (string)
});
exports.TypeaheadSearchAnswer = zod_1.z.object({
    type: zod_1.z.literal('typeaheadSearch'), // The type of answer
    answer: zod_1.z.string() // The answer to the typeahead search (string)
});
exports.URLAnswer = zod_1.z.object({
    type: zod_1.z.literal('url'), // The type of answer
    answer: zod_1.z.string() // The answer to the question (string)
});
exports.AnyAnswer = zod_1.z.discriminatedUnion('type', [
    exports.BooleanAnswer,
    exports.CheckboxesAnswer,
    exports.CurrencyAnswer,
    exports.DatePickerAnswer,
    exports.DateRangeAnswer,
    exports.EmailAnswer,
    exports.FilteredSearchAnswer,
    exports.NumberAnswer,
    exports.RadioButtonsAnswer,
    exports.SelectBoxAnswer,
    exports.TextAreaAnswer,
    exports.TextAnswer,
    exports.TypeaheadSearchAnswer,
    exports.URLAnswer
]);
exports.TableAnswer = zod_1.z.object({
    type: zod_1.z.literal('table'), // The type of answer
    answer: zod_1.z.array(exports.AnyAnswer) // The answer to the question (array of answers)
});
