"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeaheadSearchQuestion = exports.FilteredSearchQuestion = void 0;
const zod_1 = require("zod");
const primitiveQuestions_1 = require("./primitiveQuestions");
// An input variable for a GraphQL query
const GraphQLVariable = zod_1.z.object({
    minLength: zod_1.z.number().optional(), // A min length for the variable before executing the query
    label: zod_1.z.string().optional(), // The label for the variable (default to the name)
    labelTranslationKey: zod_1.z.string().optional(), // The translation key for the label (DMP Tool only)
    name: zod_1.z.string(), // MUST match the input variable name in the query
    type: zod_1.z.string(), // The type of the variable (default is string)
    defaultValue: zod_1.z.string().optional() // The default value for the variable (no default)
});
// A property from a GraphQL query response that will be displayed to the user
const GraphQLDisplayField = zod_1.z.object({
    propertyName: zod_1.z.string(), // MUST match a property name in the query response
    label: zod_1.z.string(), // The label for the field
    labelTranslationKey: zod_1.z.string().optional() // The translation key for the label (DMP Tool only)
});
// A GraphQL query object
const GraphQLQuery = zod_1.z.object({
    displayFields: zod_1.z.array(GraphQLDisplayField), // The fields to display from the query response
    localQueryId: zod_1.z.string().optional(), // The ID of the query (required if no query)
    query: zod_1.z.string().optional(), // The GraphQL query to execute (required if no localQueryId)
    responseField: zod_1.z.string(), // How to get at the location of displayFields in the response
    variables: zod_1.z.array(GraphQLVariable) // The variables for the query
});
// Filtered search question and answer
exports.FilteredSearchQuestion = primitiveQuestions_1.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('filteredSearch'), // The type of question
    graphQL: GraphQLQuery, // The GraphQL query options for the filtered search
    attributes: zod_1.z.object({
        multiple: zod_1.z.boolean().optional() // Whether to allow multiple selections (default is true)
    })
}));
// Typeahead search question and answer
exports.TypeaheadSearchQuestion = primitiveQuestions_1.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('typeaheadSearch'), // The type of question
    graphQL: GraphQLQuery, // The GraphQL query options for the typeahead search
}));
