"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SelectBoxQuestion = exports.RadioButtonsQuestion = exports.CheckboxesQuestion = void 0;
const zod_1 = require("zod");
const primitiveQuestions_1 = require("./primitiveQuestions");
// A select box, radio buttons, or checkboxes option
const Option = zod_1.z.object({
    type: zod_1.z.literal('option'), // The type of option
    attributes: zod_1.z.object({
        label: zod_1.z.string(), // The label of the option
        value: zod_1.z.string(), // The value of the option
    }),
});
const BaseOptionAttributes = Option.shape.attributes;
const CheckedOption = zod_1.z.object({
    type: zod_1.z.literal('option'),
    attributes: BaseOptionAttributes.extend({
        checked: zod_1.z.boolean().optional(),
    }),
});
const SelectedOption = zod_1.z.object({
    type: zod_1.z.literal('option'),
    attributes: BaseOptionAttributes.extend({
        selected: zod_1.z.boolean().optional(),
    }),
});
// Check boxes question and answer
exports.CheckboxesQuestion = primitiveQuestions_1.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('checkBoxes'), // The type of question
    options: zod_1.z.array(CheckedOption)
}));
// Radio buttons question and answer
exports.RadioButtonsQuestion = primitiveQuestions_1.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('radioButtons'), // The type of question
    options: zod_1.z.array(SelectedOption)
}));
// Select box question and answer
exports.SelectBoxQuestion = primitiveQuestions_1.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('selectBox'), // The type of question
    options: zod_1.z.array(SelectedOption),
    attributes: zod_1.z.object({
        multiple: zod_1.z.boolean().optional() // Whether to allow multiple selections (default is false)
    })
}));
