"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.URLQuestion = exports.TextQuestion = exports.TextAreaQuestion = exports.EmailQuestion = exports.CurrencyQuestion = exports.NumberQuestion = exports.BooleanQuestion = exports.Question = exports.QuestionTypesEnum = exports.CURRENT_SCHEMA_VERSION = void 0;
const zod_1 = require("zod");
exports.CURRENT_SCHEMA_VERSION = '1.0'; // The current schema version
// The type of question
exports.QuestionTypesEnum = zod_1.z.enum([
    'boolean',
    'checkBoxes',
    'currency',
    'datePicker',
    'dateRange',
    'email',
    'filteredSearch',
    'number',
    'option',
    'radioButtons',
    'selectBox',
    'table',
    'text',
    'textArea',
    'typeaheadSearch',
    'url'
]);
// Base abstract type for all questions
exports.Question = zod_1.z.object({
    type: exports.QuestionTypesEnum, // The type of question
    meta: zod_1.z.object({
        schemaVersion: zod_1.z.literal(exports.CURRENT_SCHEMA_VERSION), // The schema version (default is CURRENT_SCHEMA_VERSION)
        labelTranslationKey: zod_1.z.string().optional() // The translation key for the label (DMP Tool only)
    }),
});
// A Yes/No True/False question and answer
exports.BooleanQuestion = exports.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('boolean'), // The type of question
    attributes: zod_1.z.object({
        checked: zod_1.z.boolean().optional() // If it is checked by default when rendered (default is false)
    })
}));
// A number question and answer
exports.NumberQuestion = exports.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('number'), // The type of question
    attributes: zod_1.z.object({
        max: zod_1.z.number().optional(), // The maximum value (no default)
        min: zod_1.z.number().optional(), // The minimum value (default is 0)
        step: zod_1.z.number().optional() // The step value (use 0.01 or similar for float)
    })
}));
// Currency question and answer
exports.CurrencyQuestion = exports.NumberQuestion.merge(zod_1.z.object({
    type: zod_1.z.literal('currency'), // The type of question
    meta: zod_1.z.object({
        denomination: zod_1.z.string().optional() // The currency denomination (default is USD)
    })
}));
// Email question and answer
exports.EmailQuestion = exports.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('email'), // The type of question
    attributes: zod_1.z.object({
        maxLength: zod_1.z.number().optional(), // The maximum length of the email (no default)
        minLength: zod_1.z.number().optional(), // The minimum length of the email (no default)
        multiple: zod_1.z.boolean().optional(), // Allow multiple emails (default is false; comma separated)
        pattern: zod_1.z.string().optional() // The regex pattern to match (no default)
    })
}));
// Text area question and answer
exports.TextAreaQuestion = exports.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('textArea'), // The type of question
    attributes: zod_1.z.object({
        cols: zod_1.z.number().optional(), // The number of columns (default is 20)
        maxLength: zod_1.z.number().optional(), // The maximum length of the text (no default)
        minLength: zod_1.z.number().optional(), // The minimum length of the text (no default)
        rows: zod_1.z.number().optional() // The number of rows (default is 2)
    }),
    meta: zod_1.z.object({
        asRichText: zod_1.z.boolean().optional() // Whether to use rich text (default is false)
    })
}));
// Text question and answer
exports.TextQuestion = exports.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('text'), // The type of question
    attributes: zod_1.z.object({
        maxLength: zod_1.z.number().optional(), // The maximum length of the text (no default)
        minLength: zod_1.z.number().optional(), // The minimum length of the text (no default)
        pattern: zod_1.z.string().optional() // The regex pattern to match (no default)
    }),
}));
// URL question and answer
exports.URLQuestion = exports.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('url'), // The type of question
    attributes: zod_1.z.object({
        maxLength: zod_1.z.number().optional(), // The maximum length of the URL (no default)
        minLength: zod_1.z.number().optional(), // The minimum length of the URL (no default)
        pattern: zod_1.z.string().optional() // The regex pattern to match (no default)
    })
}));
