"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AnyQuestion = exports.TableQuestion = void 0;
const zod_1 = require("zod");
const primitiveQuestions_1 = require("./primitiveQuestions");
const dateQuestions_1 = require("./dateQuestions");
const optionBasedQuestions_1 = require("./optionBasedQuestions");
const graphQLQuestions_1 = require("./graphQLQuestions");
// Union types for all questions and answers (tables cannot be nested so no TableQuestion here!)
const ColumnQuestions = zod_1.z.discriminatedUnion('type', [
    primitiveQuestions_1.BooleanQuestion,
    optionBasedQuestions_1.CheckboxesQuestion,
    primitiveQuestions_1.CurrencyQuestion,
    dateQuestions_1.DatePickerQuestion,
    dateQuestions_1.DateRangeQuestion,
    primitiveQuestions_1.EmailQuestion,
    graphQLQuestions_1.FilteredSearchQuestion,
    primitiveQuestions_1.NumberQuestion,
    optionBasedQuestions_1.RadioButtonsQuestion,
    optionBasedQuestions_1.SelectBoxQuestion,
    primitiveQuestions_1.TextAreaQuestion,
    primitiveQuestions_1.TextQuestion,
    graphQLQuestions_1.TypeaheadSearchQuestion,
    primitiveQuestions_1.URLQuestion
]);
// Table question and answer
exports.TableQuestion = primitiveQuestions_1.Question.merge(zod_1.z.object({
    type: zod_1.z.literal('table'), // The type of question
    columns: zod_1.z.array(ColumnQuestions), // The columns of the table (note: tables cannot be nested)
    attributes: zod_1.z.object({
        canAddRows: zod_1.z.boolean().optional(), // Whether to allow adding rows (default is true)
        canRemoveRows: zod_1.z.boolean().optional(), // Whether to allow removing rows (default is true)
        initialRows: zod_1.z.number().optional(), // The initial number of rows (default is 1)
        maxRows: zod_1.z.number().optional(), // The maximum number of rows (no default)
        minRows: zod_1.z.number().optional() // The minimum number of rows (no default)
    })
}));
// All of the possible questions
exports.AnyQuestion = zod_1.z.discriminatedUnion('type', [
    primitiveQuestions_1.BooleanQuestion,
    optionBasedQuestions_1.CheckboxesQuestion,
    primitiveQuestions_1.CurrencyQuestion,
    dateQuestions_1.DatePickerQuestion,
    dateQuestions_1.DateRangeQuestion,
    primitiveQuestions_1.EmailQuestion,
    graphQLQuestions_1.FilteredSearchQuestion,
    primitiveQuestions_1.NumberQuestion,
    optionBasedQuestions_1.RadioButtonsQuestion,
    optionBasedQuestions_1.SelectBoxQuestion,
    exports.TableQuestion,
    primitiveQuestions_1.TextAreaQuestion,
    primitiveQuestions_1.TextQuestion,
    graphQLQuestions_1.TypeaheadSearchQuestion,
    primitiveQuestions_1.URLQuestion
]);
